==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ytbmodulewithlist/rev20160826/ytbmodulewithlist/DefaultYtblistlist.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826.ytbmodulewithlist;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of ytblistlist.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultYtblistlist extends InnerModelObject 
        implements Ytblistlist, MultiInstanceObject<YtblistlistKeys> {
    protected List<Find> prediction;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public List<Find> prediction() {
        return prediction;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void prediction(List<Find> prediction) {
        valueLeafFlags.set(LeafIdentifier.PREDICTION.getLeafIndex());
        this.prediction = prediction;
    }

    @Override
    public void addToPrediction(Find addTo) {
        if (prediction == null) {
            prediction = new ArrayList<>();
        }
        prediction.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(prediction, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultYtblistlist) {
            DefaultYtblistlist other = (DefaultYtblistlist) obj;
            return
                Objects.equals(prediction, other.prediction) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("prediction=" + prediction)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultYtblistlist.
     */
    public DefaultYtblistlist() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/ytbmodulewithlist/rev20160826/ytbmodulewithlist/DefaultYtblistlist.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ytbmodulewithlist.rev20160826.ytbmodulewithlist;

import java.util.ArrayList;
import java.util.BitSet;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;
import org.onosproject.yang.model.MultiInstanceObject;

/**
 * Represents the implementation of ytblistlist.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultYtblistlist extends InnerModelObject 
        implements Ytblistlist, MultiInstanceObject<YtblistlistKeys> {
    protected List<Find> prediction;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public List<Find> prediction() {
        return prediction;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void prediction(List<Find> prediction) {
        valueLeafFlags.set(LeafIdentifier.PREDICTION.getLeafIndex());
        this.prediction = prediction;
    }

    @Override
    public void addToPrediction(Find addTo) {
        if (prediction == null) {
            prediction = new ArrayList<>();
        }
        prediction.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(prediction, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultYtblistlist) {
            DefaultYtblistlist other = (DefaultYtblistlist) obj;
            return
                Objects.deepEquals(prediction, other.prediction) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("prediction=" + prediction)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultYtblistlist.
     */
    public DefaultYtblistlist() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
